@@ -11,6 +11,18 @@ class WiserHubRESTError(Exception):
     pass
 
 
+class WiserScheduleError(Exception):
+    pass
+
+
+class WiserScheduleInvalidTime(Exception):
+    pass
+
+
+class WiserScheduleInvalidSetting(Exception):
+    pass
+
+
 class WiserHubNotImplementedError(Exception):
     # _LOGGER.info("Function not yet implemented")
     pass
