@@ -1,3 +1,4 @@
+from ..rest_controller import _WiserRestController
 from ..const import TEXT_UNKNOWN, WISERHUBNETWORK
 
 
@@ -24,14 +25,118 @@ class _WiserDetectedNetwork:
         return self._data.get("RSSI")
 
 
+class _WiserNetworkStatistics:
+    """Data structure for network statistics"""
+
+    def __init__(self, data: dict):
+        self._data = data
+
+    @property
+    def ipv4_address_ping(self) -> str:
+        return self._data.get("IPv4AddressPing")
+
+    @property
+    def healthcheck_enabled(self) -> str:
+        return self._data.get("HealthCheckingEnabled")
+
+    @property
+    def external_ping_enabled(self) -> str:
+        return self._data.get("ExternalPingEnabled")
+
+    @property
+    def internal_ping_enabled(self) -> str:
+        return self._data.get("InternalPingEnabled")
+
+    @property
+    def dns_resolution_enabled(self) -> str:
+        return self._data.get("DnsResolutionEnabled")
+
+    @property
+    def recovery_actions(self) -> int:
+        return self._data.get("RecoveryActions")
+
+    @property
+    def external_ping_count(self) -> int:
+        return self._data.get("ExternalPing_Count")
+
+    @property
+    def internal_ping_count(self) -> int:
+        return self._data.get("InternalPing_Count")
+
+    @property
+    def internal_ping_failed_count(self) -> int:
+        return self._data.get("InternalPingFailed_Count")
+
+    @property
+    def dns_resolution_test_count(self) -> int:
+        return self._data.get("DnsResolutionTest_Count")
+
+    @property
+    def reconnection_fix_count(self) -> int:
+        return self._data.get("ReconnectionFix_Count")
+
+    @property
+    def wifi_recovery_count(self) -> int:
+        return self._data.get("HealthCheckWifiRecovery_Count")
+
+    @property
+    def wifi_total_uptime(self) -> int:
+        return self._data.get("WifiTotalUptime")
+
+    @property
+    def wifi_last_uptime(self) -> int:
+        return self._data.get("WifiLastUptime")
+
+    @property
+    def wifi_total_downtime(self) -> int:
+        return self._data.get("WifiTotalDowntime")
+
+    @property
+    def wifi_last_downtime(self) -> int:
+        return self._data.get("WifiLastDowntime")
+
+    @property
+    def wifi_channel_changes(self) -> int:
+        return self._data.get("WifiChannelChanges")
+
+    @property
+    def wifi_state_no_error_count(self) -> int:
+        return self._data.get("WifiStateNoError_Count")
+
+    @property
+    def wifi_state_ap_not_found_count(self) -> int:
+        return self._data.get("WifiStateApNotFound_Count")
+
+    @property
+    def station_disconnected_count(self) -> int:
+        return self._data.get("StationConnected_Count")
+
+    @property
+    def station_disconnected_count(self) -> int:
+        return self._data.get("StationDisconnected_Count")
+
+    @property
+    def cloud_connection_drop_count(self) -> int:
+        return self._data.get("CloudConnectionDrop_Count")
+
+    @property
+    def station_transition_to_connected_count(self) -> int:
+        return self._data.get("StationTransitionToConnected_Count")
+
+    @property
+    def station_transition_to_disconencted_count(self) -> int:
+        return self._data.get("StationTransitionToDisconnected_Count")
+
+
 class _WiserNetwork:
     """Data structure for network information for a Wiser Hub"""
 
-    def __init__(self, data: dict):
+    def __init__(self, data: dict, wiser_rest_controller: _WiserRestController):
         self._data = data
         self._dhcp_status = data.get("DhcpStatus", {})
         self._network_interface = data.get("NetworkInterface", {})
         self._detected_access_points = []
+        self._wiser_rest_controller = wiser_rest_controller
 
         for detected_network in self._data.get("DetectedAccessPoints", []):
             self._detected_access_points.append(_WiserDetectedNetwork(detected_network))
@@ -45,6 +150,11 @@ class _WiserNetwork:
         """Get the current dhcp mode of the hub"""
         return self._data.get("NetworkInterface", {}).get("DhcpMode", TEXT_UNKNOWN)
 
+    @property
+    def healthckeck_stats(self) -> _WiserNetworkStatistics:
+        """Get the network healthcheck stats of the hub"""
+        return _WiserNetworkStatistics(self._data.get("HealthCheckStats", {}))
+
     @property
     def hostname(self) -> str:
         """Get the host name of the hub"""
