@@ -1,3 +1,4 @@
+import json
 from . import _LOGGER
 
 from .const import (
@@ -16,6 +17,7 @@ from .exceptions import (
 import asyncio
 import aiohttp
 import enum
+import re
 
 from typing import Any, Optional, cast
 
@@ -69,6 +71,11 @@ class _WiserRestController(object):
         return: boolean
         """
 
+        url = url.format(
+            self._wiser_connection_info.host,
+            self._wiser_connection_info.port,
+        )
+
         kwargs = {
             "headers": {
                 "SECRET": self._wiser_connection_info.secret,
@@ -86,40 +93,43 @@ class _WiserRestController(object):
             response = cast(
                 aiohttp.ClientResponse,
                 await getattr(self._session, action.value)(
-                    url.format(
-                        self._wiser_connection_info.host,
-                        self._wiser_connection_info.port,
-                    ),
+                    url,
                     **kwargs,
                 ),
             )
 
             if not response.ok:
-                self._process_nok_response(response, raise_for_endpoint_error)
+                self._process_nok_response(
+                    response, url, data, raise_for_endpoint_error
+                )
             else:
-                #    if action == WiserRestActionEnum.GET:
-                if len(await response.text()) > 0:
-                    # response = re.sub(rb'[^\x20-\x7F]+', b'', response.content.iter_any())
-                    return await response.json()
+                content = await response.content.read()
+                if len(content) > 0:
+                    response = re.sub(rb"[^\x20-\x7F]+", b"", content)
+                    return json.loads(response)
                 else:
                     return {}
             return {}
 
         except asyncio.TimeoutError as ex:
             raise WiserHubConnectionError(
-                f"Connection timeout trying to communicate with Wiser Hub {self._wiser_connection_info.host}.  Error is {ex}"
+                f"Connection timeout trying to communicate with Wiser Hub {self._wiser_connection_info.host} for url {url}"
             )
         except aiohttp.ClientResponseError as ex:
             raise WiserHubConnectionError(
-                f"Response error trying to communicate with Wiser Hub {self._wiser_connection_info.host}.  Error is {ex}"
+                f"Response error trying to communicate with Wiser Hub {self._wiser_connection_info.host} for url {url}.  Error is {ex}"
             )
         except aiohttp.ClientConnectorError as ex:
             raise WiserHubConnectionError(
-                f"Connection error trying to communicate with Wiser Hub {self._wiser_connection_info.host}.  Error is {ex}"
+                f"Connection error trying to communicate with Wiser Hub {self._wiser_connection_info.host} for url {url}.  Error is {ex}"
             )
 
     def _process_nok_response(
-        self, response: aiohttp.ClientResponse, raise_for_endpoint_error: bool = True
+        self,
+        response: aiohttp.ClientResponse,
+        url: str,
+        data: dict,
+        raise_for_endpoint_error: bool = True,
     ):
         if response.status == 401:
             raise WiserHubAuthenticationError(
@@ -127,18 +137,16 @@ class _WiserRestController(object):
             )
         elif response.status == 404 and raise_for_endpoint_error:
             raise WiserHubRESTError(
-                f"Rest endpoint not found on Wiser Hub {self._wiser_connection_info.host}"
+                f"Rest endpoint not found on Wiser Hub {self._wiser_connection_info.host} for url {url}"
             )
         elif response.status == 408:
             raise WiserHubConnectionError(
-                f"Connection timed out trying to communicate with Wiser Hub {self._wiser_connection_info.host}"
+                f"Connection timed out trying to communicate with Wiser Hub {self._wiser_connection_info.host} for url {url}"
             )
         elif raise_for_endpoint_error:
             raise WiserHubRESTError(
-                f"Unknown error getting communicating with Wiser Hub {self._wiser_connection_info.host}.  Error code is: {response.status}"
+                f"Unknown error communicating with Wiser Hub {self._wiser_connection_info.host} for url {url} with data {data}.  Error code is: {response.status}"
             )
-        else:
-            print("Error of the Unknown kind!")
 
     async def _get_hub_data(self, url: str, raise_for_endpoint_error: bool = True):
         """Get data from hub"""
